@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Carp qw/croak/;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 require XSLoader;
 XSLoader::load('Class::XSAccessor', $VERSION);
@@ -20,6 +20,8 @@ sub import {
 
   my $read_subs = $opts{getters} || {};
   my $set_subs = $opts{setters} || {};
+  my $acc_subs = $opts{accessors} || {};
+  my $pred_subs = $opts{predicates} || {};
 
   foreach my $subname (keys %$read_subs) {
     my $hashkey = $read_subs->{$subname};
@@ -30,6 +32,16 @@ sub import {
     my $hashkey = $set_subs->{$subname};
     _generate_accessor($caller_pkg, $subname, $hashkey, $replace, "setter");
   }
+
+  foreach my $subname (keys %$acc_subs) {
+    my $hashkey = $acc_subs->{$subname};
+    _generate_accessor($caller_pkg, $subname, $hashkey, $replace, "accessor");
+  }
+
+  foreach my $subname (keys %$pred_subs) {
+    my $hashkey = $pred_subs->{$subname};
+    _generate_accessor($caller_pkg, $subname, $hashkey, $replace, "predicate");
+  }
 }
 
 sub _generate_accessor {
@@ -64,9 +76,15 @@ sub _generate_accessor {
   if ($type eq 'getter') {
     newxs_getter($subname, $hashkey);
   }
-  else {
+  elsif ($type eq 'setter') {
     newxs_setter($subname, $hashkey);
   }
+  elsif ($type eq 'predicate') {
+    newxs_predicate($subname, $hashkey);
+  }
+  else {
+    newxs_accessor($subname, $hashkey);
+  }
 }
 
 
@@ -88,21 +106,30 @@ Class::XSAccessor - Generate fast XS accessors without runtime compilation
     setters => {
       set_foo => 'foo',
       set_bar => 'bar',
-    };
+    },
+    accessors => {
+      foo => 'foo',
+      bar => 'bar',
+    },
+    predicates => {
+      has_foo => 'foo',
+      has_bar => 'bar',
+    },
   # The imported methods are implemented in fast XS.
   
   # normal class code here.
 
 =head1 DESCRIPTION
 
-The module implements fast XS accessors both for getting at and
-setting an objects attribute. The module works only with objects
-that are implement as ordinary hashes. L<Class::XSAccessor::Array>
-implements the same interface for objects that use arrays as
-internal representation.
+Class::XSAccessor implements fast read, write and read/write accessors in XS.
+Additionally, it can provide predicates such as C<has_foo()> for testing
+whether the attribute C<foo> is defined in the object.
+It only works with objects that are implemented as ordinary hashes.
+L<Class::XSAccessor::Array> implements the same interface for objects
+that use arrays for their internal representation.
 
 The XS methods were between 1.6 and 2.5 times faster than typical
-pure-perl getter and setter implementations in some simple benchmarking.
+pure-perl accessors in some simple benchmarking.
 The lower factor applies to the potentially slightly obscure
 C<sub set_foo_pp {$_[0]-E<gt>{foo} = $_[1]}>, so if you usually
 write clear code, a factor of two speed-up is a good estimate.
@@ -132,6 +159,8 @@ L<AutoXS>
 
 Steffen Mueller, E<lt>smueller@cpan.orgE<gt>
 
+Chocolateboy, E<lt>chocolate@cpan.orgE<gt>
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2008 by Steffen Mueller
